@@ -1,6 +1,6 @@
 package Sparrow;
 
-our $VERSION = '0.2.37';
+our $VERSION = '0.2.38';
 
 1;
 
@@ -797,18 +797,19 @@ they are not versioned, a simple `git clone/pull' command is executed to install
 
 =item *
 
-private plugins should be listed at sparrow plugin list file (SPL file)
+private plugins could be used by two methods:
 
 
 
 =back
 
+1) by SPL file
+2) by custom sparrow repository ( aka remote SPL file )
+
 
 =head3 SPL file
 
-Sparrow plugin list is represented by text file placed at `\~/sparrow.list'
-
-SPL file should contains lines in the following format:
+SPL file is located at `\~/sparrow.list' and contains lines in the following format:
 
 I<$plugin_name $git_repo_url>
 
@@ -842,9 +843,28 @@ Example entries:
 
 Once you add a proper entries into SPL file you may list and install a private plugins:
 
+    $ sparrow index update
     $ sparrow plg show package-generic
 
 
+=head3 Custom sparrow repository
+
+Custom sparrow repository is abstraction for I<remote SPL file>. 
+
+To use existed custom repository add this to sparrow configuration file:
+
+    $ cat ~/sparrow.yaml
+    
+    repo: 192.168.0.1:4441
+
+This entry defines a custom repository accessible at remote host 192.168.0.1 port 4441
+
+Once custom repository is set up you search and install custom repository plugins the same
+way as with private plugins defined at SPL file.
+
+To run your own sparrow custom reposository use L<Sparrow::Nest|https://github.com/melezhik/sparrow-nest> module.
+
+
 =head1 Developing sparrow plugins
 
 As sparrow support two types of plugins - swat and outthentic, follow a related documentation pages on
@@ -1074,10 +1094,13 @@ To every action you may optionally add C<--nocolor> flag to disable color output
 
 =head2 SPARROW_ROOT
 
-Sets sparrow root directory. If set than sparrow will be looking sparrow index and SPL files at following locations:
+Sets sparrow root directory. 
+
+If set than sparrow will be looking sparrow index, SPL and configuration files at following locations:
 
     $SPARROW_ROOT/sparrow.index 
     $SPARROW_ROOT/sparrow.list 
+    $SPARROW_ROOT/sparrow.yaml 
 
 As well as projects, tasks and plugins data will be kept at $SPARROW_ROOT directory.
 
@@ -1095,6 +1118,11 @@ Disable color output.
 Also see "Disable color output" section.
 
 
+=head2 SPARROWI<CONF>PATH
+
+If set defines an alternative location for sparrow configuration file.
+
+
 =head1 Remote Tasks
 
 B<I<WARNING!>> This feature is quite experimental and should be tested.
